@@ -7,6 +7,7 @@ this file contains all the helper cli commands for octogit
 import os
 import re
 import sys
+import requests
 
 from clint import args
 from clint.textui import colored, puts, indent
@@ -16,6 +17,8 @@ from .core import (get_issues, get_single_issue, create_repository,
 from .config import login, create_config, commit_changes, CONFIG_FILE
 
 
+GIT_REPO_ENDPOINT = 'https://api.github.com/repos/%s/%s'
+
 def version():
     from . import __version__
     return ".".join(str(x) for x in __version__)
@@ -42,7 +45,21 @@ def get_help():
         puts('\n')
 
 
+def get_parent_repository(username_repo):
+    username, repo = username_repo
+    url = GIT_REPO_ENDPOINT % (username, repo)
+    response = requests.get(url)
+    data = response.json
+    try:
+        parent = data['parent']['full_name']
+        username_repo = parent.split('/')
+    except KeyError:
+        pass
+    return username_repo
+
+
 def get_username_and_repo(url):
+
     # matching origin of this type
     # http://www.github.com/myusuf3/delorean
     m = re.match("^.+?github.com/([a-zA-Z0-9_-]*)/([a-zA-Z0-9_-]*)\/?$", url)
@@ -56,13 +73,15 @@ def get_username_and_repo(url):
         if username_repo[0] == '':
             username_repo = username_repo[1:]
         if len(username_repo) == 2:
-            return username_repo
+            info = username_repo
         else:
             # matching url of this type
             # git://github.com/myusuf3/delorean.git
             username_repo = url.split('/')[3:]
             username_repo[1] = username_repo[1].replace('.git', '')
-            return username_repo
+            info = username_repo
+    parent_repo = get_parent_repository(info)
+    return parent_repo
 
 
 def begin():
@@ -112,11 +131,8 @@ def begin():
                 create_issue(username, url, issue_name, description)
                 sys.exit(0)
 
-        issue_number = None
-        try:
-            issue_number = args.get(1)
-        except:
-            pass
+        issue_number = args.get(1)
+
         if issue_number is not None:
             if args.get(2) == 'close':
                 close_issue(username, url, issue_number)
